
Agility
=======

.. contents::
    :local:
    :depth: 1

Examples
++++++++

.. exreflist::
    :contents:

Ligne de commande
+++++++++++++++++

.. contents::
    :local:

Commande ``check``
^^^^^^^^^^^^^^^^^^

.. cmdref::
    :title: check
    :cmd: -m onnxcustom check --help

    Checks the module works as expected.
